#
# spec file for package ouch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ouch
Version:        0.5.1+0
Release:        1.2
Summary:        Compression and decompression utility for the terminal
License:        MIT
Group:          Productivity/Archiving/Compression
URL:            https://github.com/ouch-org/ouch
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  gcc-c++
ExclusiveArch:  %{rust_tier1_arches}

%description
The "Obvious Unified Compression Helper" is a CLI tool for
compressing and decompressing files from and to several formats.

%prep
%autosetup -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/ouch

%changelog
* Wed Dec  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.5.1:
  * Fix misleading help message
  * Fix misleading CHANGELOG and README for packages
  * Explicitly declare feature flags use_zlib & use_zstd_thin #564
* Fri Dec  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  New Features:
  * Add .rar support (decompression and listing, see clarification below) (#529)
  * Add .7z support (#555)
  Improvements:
  * Switch to the faster lz4 implementation, lz4_flex (#445)
  * Improve error message when decompressing with missing extensions (#518)
  * Strip binary when building with cargo (#535)
  * Completions: hint generator to expand to file paths (#508)
  Bug Fixes:
  * Fix size unit inconsistency (#502)
  * Fix unaligned output when using parallelism (#509)
* Tue Aug  8 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2:
  New Features:
  * Add flags to configure the compression level
  - -level to precisely set the compression level #372
  - -fast and --slow #374
  * Add --format option #341
  Improvements:
  * Multi-threaded compression for gzip and snappy using gzp #348
  * Add ls as an alternative alias for listing #360
  Bug Fixes:
  * Fix decompression of zip archives with files larger than 4GB #354
  * Fix handling of unknown extensions during decompression #355
  * Remove remaining mentions of .lz that refers to the LZMA format #344
  * Handle Zip when modification times are missing #433
* Sat Jan  7 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  New Features:
  * Add cli option to (de)compress quietly #325
  Improvements:
  * Allow ouch to decompress archive into existing folder #321
  * Accept inserting subcommand-independent flags in any position #329
  * Improve extension parsing logic #330
  * Slight refactor when ensuring archive-only inputs #331
  * Use BStr to display possibly non-UTF8 byte sequences#332
  * Use ubyte instead of humansize #333 #333
  * Stop keeping track of the names of unpacked files #334
  * Clean up #335
  Bug fixes:
  * Stop incorrectly asking to remove the parent dir #321
  * Fixed overwriting archive file when decompressing archive detected with MIME types.
  Tweaks:
  * Add scoop install instructions to readme #323
* Thu Dec  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  * More than 15 bug fixes (including major bugs).
  * New accessible mode.
  * Added list command.
  * Added support for .lz4 and .sz (snappy).
  * Infer file type while decompressing via MIME types.
  * New flags to ignore hidden files and .gitignore'd files when compressing.
  * Flag -o/--output was renamed to -d/--dir.
* Fri Nov  4 2022 Jan Engelhardt <jengelh@inai.de>
- Generalize description for all terminals and target users.
* Thu Nov  3 2022 Michael Vetter <mvetter@suse.com>
- Initial package of ouch 0.3.1 for openSUSE
